@@ -104,9 +104,9 @@ class RowDestroySignal(Signal):
     any of the post_funcs raises an exception, the deletion is only
     affected if this will prevent a commit.
 
-    You cannot cancel the delete,
-    but you can raise an exception (which will probably cancel the
-    delete, but also cause an uncaught exception if not expected).
+    You cannot cancel the delete, but you can raise an exception (which will
+    probably cancel the delete, but also cause an uncaught exception if not
+    expected).
 
     Note: this is not called when an instance is destroyed through
     garbage collection.
